#!/usr/bin/env python3

import os
import sys

from astra_installer import globvars

globvars.oem_mode = True

from astra_installer_qt.single_application import QtSingleApplication
from astra_installer_qt_oem.mainwindow import MainWindowOEM
from astra_installer.utils import Utils as BackendUtils
from astra_installer_qt.utils import Utils as InstallerUtils
from astra_installer.settings.system_locale import Locale


def main() -> None:
    # Хак для обхода проблемы с системными переводами Qt
    # Запоминаем текущую локаль
    lang = BackendUtils.get_lang()
    locale = Locale.from_string(lang).language_and_territory()
    # Принудительно устанавливаем переменную окружения LANG=en_US.UTF-8 до инициализации приложения
    os.environ['LANG'] = 'en_US.UTF-8'

    app = QtSingleApplication('astra-installer-qt-oem', sys.argv)

    if app.is_running:
        sys.exit(0)

    if not InstallerUtils.check_root_user():
        return

    main_window = MainWindowOEM(locale)
    main_window.show()

    app.activation_window = main_window

    sys.exit(app.exec_())


if __name__ == '__main__':
    main()
